@@ -316,7 +316,7 @@ resource_init(void)
 struct mblock {
   resource r;
   unsigned size;
-  uintptr_t data_align[0];
+  max_align_t data_align[0];
   byte data[0];
 };
 
